AuthenticationRepository class

Constructors

AuthenticationRepository()

Properties

hashCode → int
The hash code for this object.
no setterinherited
nonAnonymousUser → User?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uid → String?
no setter
user → User?
no setter

Methods

authStateChanges() → Stream<User?>
idTokenChanges() → Stream<User?>
isAnonymous() → bool
isSignedIn() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
signIn() → Future<UserCredential>
signInAnonymous() → Future<UserCredential>
signOut() → Future
toString() → String
A string representation of this object.
inherited
userChanges() → Stream<User?>

Operators

operator ==(Object other) → bool
The equality operator.
inherited